@@ -25,6 +25,7 @@ from spectrumx.models.captures import CaptureType
 
 from .errors import AuthError
 from .errors import CaptureError
+from .errors import DatasetError
 from .errors import FileError
 from .models.files import File
 from .models.files import FileUpload
@@ -42,7 +43,7 @@ class Endpoints(StrEnum):
 
     AUTH = "/auth"
     CAPTURES = "/assets/captures"
-    DATASETS = "/assets/datasets"
+    DATASET_FILES = "/assets/datasets/{uuid}/files"
     EXPERIMENTS = "/assets/experiments"
     FILE_CONTENTS_CHECK = "/assets/utils/check_contents_exist"
     FILE_DOWNLOAD = "/assets/files/{uuid}/download"
@@ -438,6 +439,7 @@ class GatewayClient:
         index_name: str,
         channel: str | None = None,
         scan_group: str | None = None,
+        name: str | None = None,
         verbose: bool = False,
     ) -> bytes:
         """Creates a capture on the SDS API.
@@ -447,6 +449,7 @@ class GatewayClient:
             channel:       The channel for the capture.
             capture_type:  The capture type.
             index_name:    The index name.
+            name:          Optional custom name for the capture.
         Returns:
             The response content from SDS Gateway.
         """
@@ -460,6 +463,8 @@ class GatewayClient:
             payload["channel"] = channel
         if scan_group:
             payload["scan_group"] = scan_group
+        if name:
+            payload["name"] = name
         response = self._request(
             method=HTTPMethods.POST,
             endpoint=Endpoints.CAPTURES,
@@ -584,3 +589,29 @@ class GatewayClient:
         network.success_or_raise(response, ContextException=CaptureError)
         if self.verbose:
             log.debug(f"Capture with UUID {capture_uuid} deleted successfully")
+
+    def get_dataset_files(
+        self,
+        *,
+        dataset_uuid: uuid.UUID,
+        page: int = 1,
+        page_size: int = 30,
+        verbose: bool = False,
+    ) -> bytes:
+        """Get a manifest of files in the dataset for efficient downloading.
+
+        Args:
+            dataset_uuid: The UUID of the dataset to get files for.
+            verbose: Show network requests and other info.
+        Returns:
+            The response content containing the dataset file manifest.
+        """
+        response = self._request(
+            method=HTTPMethods.GET,
+            endpoint=Endpoints.DATASET_FILES,
+            endpoint_args={"uuid": dataset_uuid.hex},
+            params={"page": page, "page_size": page_size},
+            verbose=verbose,
+        )
+        network.success_or_raise(response, ContextException=DatasetError)
+        return response.content
