@@ -1,11 +1,13 @@
 """Data models for the SpectrumX Data System SDK."""
 
 from . import captures
+from . import datasets
 from . import files
 from .base import SDSModel
 
 __all__ = [
     "SDSModel",
     "captures",
+    "datasets",
     "files",
 ]
